@@ -235,7 +235,7 @@ class DataSet(pd.DataFrame):
             else:
                 raise ValueError(f"{key} is not an instance of type str, np.ndarray, pd.Index, pd.Series, or list")
             
-        return super().set_index(keys, drop, append, inplace, verify_integrity)
+        return super().set_index(keys, drop=drop, append=append, inplace=inplace, verify_integrity=verify_integrity)
 
     def reset_index(self, level=None, drop=False, inplace=False, col_level=0, col_fill=''):
         """
@@ -289,11 +289,11 @@ class DataSet(pd.DataFrame):
             return dataset
         
         if inplace:
-            super().reset_index(level, drop, inplace, col_level, col_fill)
+            super().reset_index(level, drop=drop, inplace=inplace, col_level=col_level, col_fill=col_fill)
             _handle_cached_dtypes(self, columns, drop)
             return
         else:
-            dataset = super().reset_index(level, drop, inplace, col_level, col_fill)
+            dataset = super().reset_index(level, drop=drop, inplace=inplace, col_level=col_level, col_fill=col_fill)
             dataset._index_dtypes = dataset._index_dtypes.copy()
             dataset = _handle_cached_dtypes(dataset, columns, drop)
             return dataset
@@ -347,6 +347,24 @@ class DataSet(pd.DataFrame):
         from reciprocalspaceship import io
         return io.to_gemmi(self, skip_problem_mtztypes)
 
+    def to_pickle(self, path, *args, **kwargs):
+        """
+        Pickle object to file.
+
+        This can be useful for saving non-MTZ compatible data files for future use. For additional documentation on accepted arguments, see the
+        `Pandas DataFrame.to_pickle() API <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_pickle.html>`_.
+
+        Parameters
+        ----------
+        path : str
+            File path where the pickled object will be stored.
+
+        See Also
+        --------
+        read_pickle() : Load pickled reciprocalspaceship object from file.
+        """
+        return super().to_pickle(path, *args, **kwargs)
+    
     def to_structurefactor(self, sf_key, phase_key):
         """
         Convert structure factor amplitudes and phases to complex structure
@@ -597,11 +615,10 @@ class DataSet(pd.DataFrame):
 
         # Shift phases according to symop
         for key in dataset.get_phase_keys():
-            dataset[key] += np.rad2deg(phase_shifts)
-            dataset[key] *= phic
+            dataset[key] = phic * (dataset[key] - np.rad2deg(phase_shifts))
             dataset[key] = utils.canonicalize_phases(dataset[key], deg=True)
         for key in dataset.get_complex_keys():
-            dataset[key] *= np.exp(1j*phase_shifts)
+            dataset[key] *= np.exp(-1j*phase_shifts)
             if symop.det_rot() < 0:
                 dataset[key] = np.conjugate(dataset[key])
         
@@ -1001,7 +1018,12 @@ class DataSet(pd.DataFrame):
         for k in dataset.get_phase_keys():
             dataset[k] = phi_coeff[inverse] * (dataset[k] + phi_shift[inverse])
         dataset.canonicalize_phases(inplace=True)
-
+        # GH#15: Handle complex structure factors
+        for k in dataset.get_complex_keys():
+            self[k] *= np.exp(1j*np.deg2rad(phi_shift[inverse]))
+            friedel_mask = phi_coeff[inverse] != 1
+            self.loc[friedel_mask, k] = np.conjugate(self.loc[friedel_mask, k])
+        
         # GH#3: if PARTIAL column exists, use it to construct M/ISYM
         if "PARTIAL" in dataset.columns:
             m_isym = isym[inverse] + 256*dataset["PARTIAL"].to_numpy()
@@ -1086,10 +1108,16 @@ class DataSet(pd.DataFrame):
         # Apply phase shift
         for k in self.get_phase_keys():
             self[k] = phi_coeff[inverse] * (self[k] + phi_shift[inverse])
+        # GH#15: Handle complex structure factors
+        for k in self.get_complex_keys():
+            self[k] *= np.exp(1j*np.deg2rad(phi_shift[inverse]))
+            friedel_mask = phi_coeff[inverse] != 1
+            self.loc[friedel_mask, k] = np.conjugate(self.loc[friedel_mask, k])
         self.canonicalize_phases(inplace=True)
         
         return self
 
+    @range_indexed
     def expand_to_p1(self):
         """
         Generates all symmetrically equivalent reflections. The spacegroup 
@@ -1101,13 +1129,27 @@ class DataSet(pd.DataFrame):
         """
         if not self.merged:
             raise ValueError("This function is only applicable for merged DataSets")
+        if not in_asu(self.get_hkls(), spacegroup=self.spacegroup).all():
+            raise ValueError("This function is only  applicable for reflection data in the reciprocal ASU and anomalous data in a two-column (unstacked) format")
 
+        p1 = rs.DataSet(spacegroup=self.spacegroup, cell=self.cell)        
+
+        # Get all symops, in ascending order by ISYM
         groupops = self.spacegroup.operations()
-        p1 = rs.concat([ self.apply_symop(op) for op in groupops ])
+        allops = [ op for op in groupops for op in (op, op.negated()) ]
+
+        # Apply each symop and drop duplicates with higher ISYM
+        for isym, op in enumerate(allops, 1):
+            ds = self.copy()
+            ds["M/ISYM"] = isym
+            ds["M/ISYM"] = ds["M/ISYM"].astype("M/ISYM")
+            p1 = p1.append(ds.hkl_to_observed(m_isym="M/ISYM"))
+            p1.drop_duplicates(subset=["H", "K", "L"], inplace=True)
+
+        # Restrict to p1 ASU
         p1.spacegroup = gemmi.SpaceGroup(1)
-        p1.reset_index(inplace=True)
-        p1.drop_duplicates(subset=["H", "K", "L"], inplace=True)
-        p1.set_index(["H", "K", "L"], inplace=True)
+        p1 = p1.loc[in_asu(p1.get_hkls(), spacegroup=p1.spacegroup)]
+
         return p1
 
     def expand_anomalous(self):
@@ -1144,7 +1186,7 @@ class DataSet(pd.DataFrame):
 
         return self
 
-    def to_reciprocalgrid(self, key, gridsize, friedels_law=True):
+    def to_reciprocalgrid(self, key, gridsize):
         """
         Set up reciprocal grid with values from column, ``key``, indexed by
         Miller indices. A 3D numpy array will be initialized with the
@@ -1155,11 +1197,6 @@ class DataSet(pd.DataFrame):
         -----
         - The data being arranged on a reciprocal grid must be compatible
           with a numpy datatype.
-        - If the data is complex and ``friedels_law=True``, the complex
-          conjugate will be used to populate Friedel pairs. The only scenario
-          in which to use ``friedels_law=False`` would be if Friedel pairs
-          have already been stacked to go from two-column to one-column
-          anomalous data. 
         
         Parameters
         ----------
@@ -1167,21 +1204,21 @@ class DataSet(pd.DataFrame):
             Column label for value to arrange on reciprocal grid
         gridsize : array-like (len==3)
             Dimensions for 3D reciprocal grid.
-        friedels_law : bool
-            Whether to expand data from P1 ASU to P1 unit cell when constructing
-            reciprocal grid. If False, Friedel pairs must be handled by
-            the user
 
         Returns
         -------
         numpy.ndarray
         """
+        # Set up P1 unit cell
         p1 = self.expand_to_p1()
-        if friedels_law:
-            p1 = p1.expand_anomalous()
-        p1.sort_index(inplace=True)
+        p1 = p1.expand_anomalous()
+
+        # Get data and indices
         data = p1[key].to_numpy()
         H = p1.get_hkls()
+
+        # Populate grid
         grid = np.zeros(gridsize, dtype=data.dtype)
         grid[H[:, 0], H[:, 1], H[:, 2]] = data
+
         return grid
